# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['StorageEfsShareAclArgs', 'StorageEfsShareAcl']

@pulumi.input_type
class StorageEfsShareAclArgs:
    def __init__(__self__, *,
                 access_level: pulumi.Input[_builtins.str],
                 access_to: pulumi.Input[_builtins.str],
                 service_name: pulumi.Input[_builtins.str],
                 share_id: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a StorageEfsShareAcl resource.
        :param pulumi.Input[_builtins.str] access_level: Rule access level
        :param pulumi.Input[_builtins.str] access_to: Rule destination
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        """
        pulumi.set(__self__, "access_level", access_level)
        pulumi.set(__self__, "access_to", access_to)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "share_id", share_id)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> pulumi.Input[_builtins.str]:
        """
        Rule access level
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "access_level", value)

    @_builtins.property
    @pulumi.getter(name="accessTo")
    def access_to(self) -> pulumi.Input[_builtins.str]:
        """
        Rule destination
        """
        return pulumi.get(self, "access_to")

    @access_to.setter
    def access_to(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "access_to", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> pulumi.Input[_builtins.str]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @share_id.setter
    def share_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "share_id", value)


@pulumi.input_type
class _StorageEfsShareAclState:
    def __init__(__self__, *,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 access_to: Optional[pulumi.Input[_builtins.str]] = None,
                 access_type: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering StorageEfsShareAcl resources.
        :param pulumi.Input[_builtins.str] access_level: Rule access level
        :param pulumi.Input[_builtins.str] access_to: Rule destination
        :param pulumi.Input[_builtins.str] access_type: Rule access type
        :param pulumi.Input[_builtins.str] created_at: Rule creation date
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        :param pulumi.Input[_builtins.str] status: Rule status
        """
        if access_level is not None:
            pulumi.set(__self__, "access_level", access_level)
        if access_to is not None:
            pulumi.set(__self__, "access_to", access_to)
        if access_type is not None:
            pulumi.set(__self__, "access_type", access_type)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if share_id is not None:
            pulumi.set(__self__, "share_id", share_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule access level
        """
        return pulumi.get(self, "access_level")

    @access_level.setter
    def access_level(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_level", value)

    @_builtins.property
    @pulumi.getter(name="accessTo")
    def access_to(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule destination
        """
        return pulumi.get(self, "access_to")

    @access_to.setter
    def access_to(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_to", value)

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule access type
        """
        return pulumi.get(self, "access_type")

    @access_type.setter
    def access_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "access_type", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule creation date
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @share_id.setter
    def share_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "share_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rule status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:index/storageEfsShareAcl:StorageEfsShareAcl")
class StorageEfsShareAcl(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 access_to: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates an ACL rule for an EFS share.

        Please take a look at the list of available `access_level` values in the `Required` section in order to know the list of supported access level configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        efs = ovh.get_storage_efs(service_name="XXX")
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        acl = ovh.StorageEfsShareAcl("acl",
            service_name=efs.service_name,
            share_id=share.id,
            access_level="ro",
            access_to="10.0.0.1")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_level: Rule access level
        :param pulumi.Input[_builtins.str] access_to: Rule destination
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StorageEfsShareAclArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates an ACL rule for an EFS share.

        Please take a look at the list of available `access_level` values in the `Required` section in order to know the list of supported access level configurations.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        efs = ovh.get_storage_efs(service_name="XXX")
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        acl = ovh.StorageEfsShareAcl("acl",
            service_name=efs.service_name,
            share_id=share.id,
            access_level="ro",
            access_to="10.0.0.1")
        ```

        :param str resource_name: The name of the resource.
        :param StorageEfsShareAclArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StorageEfsShareAclArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 access_level: Optional[pulumi.Input[_builtins.str]] = None,
                 access_to: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 share_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StorageEfsShareAclArgs.__new__(StorageEfsShareAclArgs)

            if access_level is None and not opts.urn:
                raise TypeError("Missing required property 'access_level'")
            __props__.__dict__["access_level"] = access_level
            if access_to is None and not opts.urn:
                raise TypeError("Missing required property 'access_to'")
            __props__.__dict__["access_to"] = access_to
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if share_id is None and not opts.urn:
                raise TypeError("Missing required property 'share_id'")
            __props__.__dict__["share_id"] = share_id
            __props__.__dict__["access_type"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
        super(StorageEfsShareAcl, __self__).__init__(
            'ovh:index/storageEfsShareAcl:StorageEfsShareAcl',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            access_level: Optional[pulumi.Input[_builtins.str]] = None,
            access_to: Optional[pulumi.Input[_builtins.str]] = None,
            access_type: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            share_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'StorageEfsShareAcl':
        """
        Get an existing StorageEfsShareAcl resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] access_level: Rule access level
        :param pulumi.Input[_builtins.str] access_to: Rule destination
        :param pulumi.Input[_builtins.str] access_type: Rule access type
        :param pulumi.Input[_builtins.str] created_at: Rule creation date
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.str] share_id: Share ID
        :param pulumi.Input[_builtins.str] status: Rule status
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StorageEfsShareAclState.__new__(_StorageEfsShareAclState)

        __props__.__dict__["access_level"] = access_level
        __props__.__dict__["access_to"] = access_to
        __props__.__dict__["access_type"] = access_type
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["share_id"] = share_id
        __props__.__dict__["status"] = status
        return StorageEfsShareAcl(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="accessLevel")
    def access_level(self) -> pulumi.Output[_builtins.str]:
        """
        Rule access level
        """
        return pulumi.get(self, "access_level")

    @_builtins.property
    @pulumi.getter(name="accessTo")
    def access_to(self) -> pulumi.Output[_builtins.str]:
        """
        Rule destination
        """
        return pulumi.get(self, "access_to")

    @_builtins.property
    @pulumi.getter(name="accessType")
    def access_type(self) -> pulumi.Output[_builtins.str]:
        """
        Rule access type
        """
        return pulumi.get(self, "access_type")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Rule creation date
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> pulumi.Output[_builtins.str]:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Rule status
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetLoadBalancersResult',
    'AwaitableGetLoadBalancersResult',
    'get_load_balancers',
    'get_load_balancers_output',
]

@pulumi.output_type
class GetLoadBalancersResult:
    """
    A collection of values returned by getLoadBalancers.
    """
    def __init__(__self__, id=None, loadbalancers=None, region_name=None, service_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if loadbalancers and not isinstance(loadbalancers, list):
            raise TypeError("Expected argument 'loadbalancers' to be a list")
        pulumi.set(__self__, "loadbalancers", loadbalancers)
        if region_name and not isinstance(region_name, str):
            raise TypeError("Expected argument 'region_name' to be a str")
        pulumi.set(__self__, "region_name", region_name)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def loadbalancers(self) -> Sequence['outputs.GetLoadBalancersLoadbalancerResult']:
        """
        List of loadbalancer
        """
        return pulumi.get(self, "loadbalancers")

    @_builtins.property
    @pulumi.getter(name="regionName")
    def region_name(self) -> _builtins.str:
        """
        Region of the loadbalancers
        """
        return pulumi.get(self, "region_name")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        ID of the public cloud project
        """
        return pulumi.get(self, "service_name")


class AwaitableGetLoadBalancersResult(GetLoadBalancersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetLoadBalancersResult(
            id=self.id,
            loadbalancers=self.loadbalancers,
            region_name=self.region_name,
            service_name=self.service_name)


def get_load_balancers(region_name: Optional[_builtins.str] = None,
                       service_name: Optional[_builtins.str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetLoadBalancersResult:
    """
    List your public cloud loadbalancers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lbs = ovh.CloudProject.get_load_balancers(service_name="XXXXXX",
        region_name="XXX")
    pulumi.export("lbs", lbs)
    ```


    :param _builtins.str region_name: Region of the loadbalancers.
    :param _builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getLoadBalancers:getLoadBalancers', __args__, opts=opts, typ=GetLoadBalancersResult).value

    return AwaitableGetLoadBalancersResult(
        id=pulumi.get(__ret__, 'id'),
        loadbalancers=pulumi.get(__ret__, 'loadbalancers'),
        region_name=pulumi.get(__ret__, 'region_name'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_load_balancers_output(region_name: Optional[pulumi.Input[_builtins.str]] = None,
                              service_name: Optional[pulumi.Input[_builtins.str]] = None,
                              opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetLoadBalancersResult]:
    """
    List your public cloud loadbalancers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    lbs = ovh.CloudProject.get_load_balancers(service_name="XXXXXX",
        region_name="XXX")
    pulumi.export("lbs", lbs)
    ```


    :param _builtins.str region_name: Region of the loadbalancers.
    :param _builtins.str service_name: The ID of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['regionName'] = region_name
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getLoadBalancers:getLoadBalancers', __args__, opts=opts, typ=GetLoadBalancersResult)
    return __ret__.apply(lambda __response__: GetLoadBalancersResult(
        id=pulumi.get(__response__, 'id'),
        loadbalancers=pulumi.get(__response__, 'loadbalancers'),
        region_name=pulumi.get(__response__, 'region_name'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetCloudProjectRancherCapabilitiesPlanResult',
    'AwaitableGetCloudProjectRancherCapabilitiesPlanResult',
    'get_cloud_project_rancher_capabilities_plan',
    'get_cloud_project_rancher_capabilities_plan_output',
]

@pulumi.output_type
class GetCloudProjectRancherCapabilitiesPlanResult:
    """
    A collection of values returned by getCloudProjectRancherCapabilitiesPlan.
    """
    def __init__(__self__, id=None, plans=None, project_id=None, rancher_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if plans and not isinstance(plans, list):
            raise TypeError("Expected argument 'plans' to be a list")
        pulumi.set(__self__, "plans", plans)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if rancher_id and not isinstance(rancher_id, str):
            raise TypeError("Expected argument 'rancher_id' to be a str")
        pulumi.set(__self__, "rancher_id", rancher_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def plans(self) -> Sequence['outputs.GetCloudProjectRancherCapabilitiesPlanPlanResult']:
        return pulumi.get(self, "plans")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        """
        Project ID
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="rancherId")
    def rancher_id(self) -> _builtins.str:
        """
        Rancher ID
        """
        return pulumi.get(self, "rancher_id")


class AwaitableGetCloudProjectRancherCapabilitiesPlanResult(GetCloudProjectRancherCapabilitiesPlanResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCloudProjectRancherCapabilitiesPlanResult(
            id=self.id,
            plans=self.plans,
            project_id=self.project_id,
            rancher_id=self.rancher_id)


def get_cloud_project_rancher_capabilities_plan(project_id: Optional[_builtins.str] = None,
                                                rancher_id: Optional[_builtins.str] = None,
                                                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCloudProjectRancherCapabilitiesPlanResult:
    """
    List available and current plans for the given managed Rancher service

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    plans = ovh.get_cloud_project_rancher_capabilities_plan(project_id="XXX",
        rancher_id="YYY")
    ```


    :param _builtins.str project_id: Project ID
    :param _builtins.str rancher_id: Rancher ID
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['rancherId'] = rancher_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getCloudProjectRancherCapabilitiesPlan:getCloudProjectRancherCapabilitiesPlan', __args__, opts=opts, typ=GetCloudProjectRancherCapabilitiesPlanResult).value

    return AwaitableGetCloudProjectRancherCapabilitiesPlanResult(
        id=pulumi.get(__ret__, 'id'),
        plans=pulumi.get(__ret__, 'plans'),
        project_id=pulumi.get(__ret__, 'project_id'),
        rancher_id=pulumi.get(__ret__, 'rancher_id'))
def get_cloud_project_rancher_capabilities_plan_output(project_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                       rancher_id: Optional[pulumi.Input[_builtins.str]] = None,
                                                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCloudProjectRancherCapabilitiesPlanResult]:
    """
    List available and current plans for the given managed Rancher service

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    plans = ovh.get_cloud_project_rancher_capabilities_plan(project_id="XXX",
        rancher_id="YYY")
    ```


    :param _builtins.str project_id: Project ID
    :param _builtins.str rancher_id: Rancher ID
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['rancherId'] = rancher_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getCloudProjectRancherCapabilitiesPlan:getCloudProjectRancherCapabilitiesPlan', __args__, opts=opts, typ=GetCloudProjectRancherCapabilitiesPlanResult)
    return __ret__.apply(lambda __response__: GetCloudProjectRancherCapabilitiesPlanResult(
        id=pulumi.get(__response__, 'id'),
        plans=pulumi.get(__response__, 'plans'),
        project_id=pulumi.get(__response__, 'project_id'),
        rancher_id=pulumi.get(__response__, 'rancher_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetStorageEfsShareAccessPathResult',
    'AwaitableGetStorageEfsShareAccessPathResult',
    'get_storage_efs_share_access_path',
    'get_storage_efs_share_access_path_output',
]

@pulumi.output_type
class GetStorageEfsShareAccessPathResult:
    """
    A collection of values returned by getStorageEfsShareAccessPath.
    """
    def __init__(__self__, id=None, path=None, preferred=None, service_name=None, share_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if preferred and not isinstance(preferred, bool):
            raise TypeError("Expected argument 'preferred' to be a bool")
        pulumi.set(__self__, "preferred", preferred)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if share_id and not isinstance(share_id, str):
            raise TypeError("Expected argument 'share_id' to be a str")
        pulumi.set(__self__, "share_id", share_id)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Access path ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        Access path
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter
    def preferred(self) -> _builtins.bool:
        """
        Is this the preferred access path?
        """
        return pulumi.get(self, "preferred")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter(name="shareId")
    def share_id(self) -> _builtins.str:
        """
        Share ID
        """
        return pulumi.get(self, "share_id")


class AwaitableGetStorageEfsShareAccessPathResult(GetStorageEfsShareAccessPathResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageEfsShareAccessPathResult(
            id=self.id,
            path=self.path,
            preferred=self.preferred,
            service_name=self.service_name,
            share_id=self.share_id)


def get_storage_efs_share_access_path(id: Optional[_builtins.str] = None,
                                      service_name: Optional[_builtins.str] = None,
                                      share_id: Optional[_builtins.str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageEfsShareAccessPathResult:
    """
    Get access path detailed information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    efs = ovh.get_storage_efs(service_name="XXX")
    access_path = ovh.get_storage_efs_share_access_path(service_name=efs.service_name,
        share_id="XXX",
        id="XXX")
    ```


    :param _builtins.str id: Access path ID
    :param _builtins.str service_name: Service name
    :param _builtins.str share_id: Share ID
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['serviceName'] = service_name
    __args__['shareId'] = share_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getStorageEfsShareAccessPath:getStorageEfsShareAccessPath', __args__, opts=opts, typ=GetStorageEfsShareAccessPathResult).value

    return AwaitableGetStorageEfsShareAccessPathResult(
        id=pulumi.get(__ret__, 'id'),
        path=pulumi.get(__ret__, 'path'),
        preferred=pulumi.get(__ret__, 'preferred'),
        service_name=pulumi.get(__ret__, 'service_name'),
        share_id=pulumi.get(__ret__, 'share_id'))
def get_storage_efs_share_access_path_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                                             service_name: Optional[pulumi.Input[_builtins.str]] = None,
                                             share_id: Optional[pulumi.Input[_builtins.str]] = None,
                                             opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageEfsShareAccessPathResult]:
    """
    Get access path detailed information.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    efs = ovh.get_storage_efs(service_name="XXX")
    access_path = ovh.get_storage_efs_share_access_path(service_name=efs.service_name,
        share_id="XXX",
        id="XXX")
    ```


    :param _builtins.str id: Access path ID
    :param _builtins.str service_name: Service name
    :param _builtins.str share_id: Share ID
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['serviceName'] = service_name
    __args__['shareId'] = share_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getStorageEfsShareAccessPath:getStorageEfsShareAccessPath', __args__, opts=opts, typ=GetStorageEfsShareAccessPathResult)
    return __ret__.apply(lambda __response__: GetStorageEfsShareAccessPathResult(
        id=pulumi.get(__response__, 'id'),
        path=pulumi.get(__response__, 'path'),
        preferred=pulumi.get(__response__, 'preferred'),
        service_name=pulumi.get(__response__, 'service_name'),
        share_id=pulumi.get(__response__, 'share_id')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['StorageEfsShareArgs', 'StorageEfsShare']

@pulumi.input_type
class StorageEfsShareArgs:
    def __init__(__self__, *,
                 protocol: pulumi.Input[_builtins.str],
                 service_name: pulumi.Input[_builtins.str],
                 size: pulumi.Input[_builtins.float],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a StorageEfsShare resource.
        :param pulumi.Input[_builtins.str] protocol: Share protocol
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.float] size: Share size in Gigabytes
        :param pulumi.Input[_builtins.str] description: Share description
        :param pulumi.Input[_builtins.str] mount_point_name: User-defined name used to generate human readable access path for the share
        :param pulumi.Input[_builtins.str] name: Share name
        :param pulumi.Input[_builtins.str] snapshot_id: Snapshot ID used to create the share
        """
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "size", size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[_builtins.str]:
        """
        Share protocol
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Input[_builtins.float]:
        """
        Share size in Gigabytes
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[_builtins.float]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-defined name used to generate human readable access path for the share
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mount_point_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot ID used to create the share
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snapshot_id", value)


@pulumi.input_type
class _StorageEfsShareState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering StorageEfsShare resources.
        :param pulumi.Input[_builtins.str] created_at: Share creation date
        :param pulumi.Input[_builtins.str] description: Share description
        :param pulumi.Input[_builtins.str] mount_point_name: User-defined name used to generate human readable access path for the share
        :param pulumi.Input[_builtins.str] name: Share name
        :param pulumi.Input[_builtins.str] protocol: Share protocol
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.float] size: Share size in Gigabytes
        :param pulumi.Input[_builtins.str] snapshot_id: Snapshot ID used to create the share
        :param pulumi.Input[_builtins.str] status: Share status
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if mount_point_name is not None:
            pulumi.set(__self__, "mount_point_name", mount_point_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if snapshot_id is not None:
            pulumi.set(__self__, "snapshot_id", snapshot_id)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share creation date
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User-defined name used to generate human readable access path for the share
        """
        return pulumi.get(self, "mount_point_name")

    @mount_point_name.setter
    def mount_point_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "mount_point_name", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share protocol
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "protocol", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[_builtins.float]]:
        """
        Share size in Gigabytes
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[_builtins.float]]):
        pulumi.set(self, "size", value)

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Snapshot ID used to create the share
        """
        return pulumi.get(self, "snapshot_id")

    @snapshot_id.setter
    def snapshot_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "snapshot_id", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Share status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)


@pulumi.type_token("ovh:index/storageEfsShare:StorageEfsShare")
class StorageEfsShare(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Creates a share for an EFS service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        efs = ovh.get_storage_efs(service_name="XXX")
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Share description
        :param pulumi.Input[_builtins.str] mount_point_name: User-defined name used to generate human readable access path for the share
        :param pulumi.Input[_builtins.str] name: Share name
        :param pulumi.Input[_builtins.str] protocol: Share protocol
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.float] size: Share size in Gigabytes
        :param pulumi.Input[_builtins.str] snapshot_id: Snapshot ID used to create the share
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: StorageEfsShareArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a share for an EFS service.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        efs = ovh.get_storage_efs(service_name="XXX")
        share = ovh.StorageEfsShare("share",
            service_name=efs.service_name,
            name="share",
            description="My share",
            protocol="NFS",
            size=100)
        ```

        :param str resource_name: The name of the resource.
        :param StorageEfsShareArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(StorageEfsShareArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 mount_point_name: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 protocol: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 size: Optional[pulumi.Input[_builtins.float]] = None,
                 snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = StorageEfsShareArgs.__new__(StorageEfsShareArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["mount_point_name"] = mount_point_name
            __props__.__dict__["name"] = name
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["snapshot_id"] = snapshot_id
            __props__.__dict__["created_at"] = None
            __props__.__dict__["status"] = None
        super(StorageEfsShare, __self__).__init__(
            'ovh:index/storageEfsShare:StorageEfsShare',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            mount_point_name: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            protocol: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            size: Optional[pulumi.Input[_builtins.float]] = None,
            snapshot_id: Optional[pulumi.Input[_builtins.str]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None) -> 'StorageEfsShare':
        """
        Get an existing StorageEfsShare resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Share creation date
        :param pulumi.Input[_builtins.str] description: Share description
        :param pulumi.Input[_builtins.str] mount_point_name: User-defined name used to generate human readable access path for the share
        :param pulumi.Input[_builtins.str] name: Share name
        :param pulumi.Input[_builtins.str] protocol: Share protocol
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[_builtins.float] size: Share size in Gigabytes
        :param pulumi.Input[_builtins.str] snapshot_id: Snapshot ID used to create the share
        :param pulumi.Input[_builtins.str] status: Share status
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _StorageEfsShareState.__new__(_StorageEfsShareState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["mount_point_name"] = mount_point_name
        __props__.__dict__["name"] = name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size"] = size
        __props__.__dict__["snapshot_id"] = snapshot_id
        __props__.__dict__["status"] = status
        return StorageEfsShare(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Share creation date
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[_builtins.str]:
        """
        Share description
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="mountPointName")
    def mount_point_name(self) -> pulumi.Output[_builtins.str]:
        """
        User-defined name used to generate human readable access path for the share
        """
        return pulumi.get(self, "mount_point_name")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Share name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[_builtins.str]:
        """
        Share protocol
        """
        return pulumi.get(self, "protocol")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def size(self) -> pulumi.Output[_builtins.float]:
        """
        Share size in Gigabytes
        """
        return pulumi.get(self, "size")

    @_builtins.property
    @pulumi.getter(name="snapshotId")
    def snapshot_id(self) -> pulumi.Output[_builtins.str]:
        """
        Snapshot ID used to create the share
        """
        return pulumi.get(self, "snapshot_id")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Share status
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectRegionArgs', 'ProjectRegion']

@pulumi.input_type
class ProjectRegionArgs:
    def __init__(__self__, *,
                 region: pulumi.Input[_builtins.str],
                 service_name: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a ProjectRegion resource.
        :param pulumi.Input[_builtins.str] region: Region to add to your project
        :param pulumi.Input[_builtins.str] service_name: Service name
        """
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Input[_builtins.str]:
        """
        Region to add to your project
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _ProjectRegionState:
    def __init__(__self__, *,
                 availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 continent_code: Optional[pulumi.Input[_builtins.str]] = None,
                 country_code: Optional[pulumi.Input[_builtins.str]] = None,
                 datacenter_location: Optional[pulumi.Input[_builtins.str]] = None,
                 ip_countries: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 region_name: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 services: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRegionServiceArgs']]]] = None,
                 status: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectRegion resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: Availability zones of the region
        :param pulumi.Input[_builtins.str] continent_code: Region continent code
        :param pulumi.Input[_builtins.str] country_code: Region country code
        :param pulumi.Input[_builtins.str] datacenter_location: Location of the datacenter where the region is
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_countries: Allowed countries for failover ip
        :param pulumi.Input[_builtins.str] name: Region name
        :param pulumi.Input[_builtins.str] region: Region to add to your project
        :param pulumi.Input[_builtins.str] region_name: Region name
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[Sequence[pulumi.Input['ProjectRegionServiceArgs']]] services: Details about components status
        :param pulumi.Input[_builtins.str] status: Openstack region status
        :param pulumi.Input[_builtins.str] type: Region type
        """
        if availability_zones is not None:
            pulumi.set(__self__, "availability_zones", availability_zones)
        if continent_code is not None:
            pulumi.set(__self__, "continent_code", continent_code)
        if country_code is not None:
            pulumi.set(__self__, "country_code", country_code)
        if datacenter_location is not None:
            pulumi.set(__self__, "datacenter_location", datacenter_location)
        if ip_countries is not None:
            pulumi.set(__self__, "ip_countries", ip_countries)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if services is not None:
            pulumi.set(__self__, "services", services)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if type is not None:
            pulumi.set(__self__, "type", type)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Availability zones of the region
        """
        return pulumi.get(self, "availability_zones")

    @availability_zones.setter
    def availability_zones(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "availability_zones", value)

    @_builtins.property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region continent code
        """
        return pulumi.get(self, "continent_code")

    @continent_code.setter
    def continent_code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "continent_code", value)

    @_builtins.property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region country code
        """
        return pulumi.get(self, "country_code")

    @country_code.setter
    def country_code(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "country_code", value)

    @_builtins.property
    @pulumi.getter(name="datacenterLocation")
    def datacenter_location(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Location of the datacenter where the region is
        """
        return pulumi.get(self, "datacenter_location")

    @datacenter_location.setter
    def datacenter_location(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "datacenter_location", value)

    @_builtins.property
    @pulumi.getter(name="ipCountries")
    def ip_countries(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Allowed countries for failover ip
        """
        return pulumi.get(self, "ip_countries")

    @ip_countries.setter
    def ip_countries(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "ip_countries", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region to add to your project
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region", value)

    @_builtins.property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "region_name", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)

    @_builtins.property
    @pulumi.getter
    def services(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRegionServiceArgs']]]]:
        """
        Details about components status
        """
        return pulumi.get(self, "services")

    @services.setter
    def services(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectRegionServiceArgs']]]]):
        pulumi.set(self, "services", value)

    @_builtins.property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Openstack region status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "status", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Region type
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)


@pulumi.type_token("ovh:CloudProject/projectRegion:ProjectRegion")
class ProjectRegion(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        region = ovh.cloudproject.ProjectRegion("region",
            service_name="<public cloud project ID>",
            region="EU-WEST-LZ-LUX-A")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] region: Region to add to your project
        :param pulumi.Input[_builtins.str] service_name: Service name
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectRegionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        region = ovh.cloudproject.ProjectRegion("region",
            service_name="<public cloud project ID>",
            region="EU-WEST-LZ-LUX-A")
        ```

        :param str resource_name: The name of the resource.
        :param ProjectRegionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectRegionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 region: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectRegionArgs.__new__(ProjectRegionArgs)

            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["availability_zones"] = None
            __props__.__dict__["continent_code"] = None
            __props__.__dict__["country_code"] = None
            __props__.__dict__["datacenter_location"] = None
            __props__.__dict__["ip_countries"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["region_name"] = None
            __props__.__dict__["services"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["type"] = None
        super(ProjectRegion, __self__).__init__(
            'ovh:CloudProject/projectRegion:ProjectRegion',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zones: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            continent_code: Optional[pulumi.Input[_builtins.str]] = None,
            country_code: Optional[pulumi.Input[_builtins.str]] = None,
            datacenter_location: Optional[pulumi.Input[_builtins.str]] = None,
            ip_countries: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            region: Optional[pulumi.Input[_builtins.str]] = None,
            region_name: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None,
            services: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectRegionServiceArgs', 'ProjectRegionServiceArgsDict']]]]] = None,
            status: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectRegion':
        """
        Get an existing ProjectRegion resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] availability_zones: Availability zones of the region
        :param pulumi.Input[_builtins.str] continent_code: Region continent code
        :param pulumi.Input[_builtins.str] country_code: Region country code
        :param pulumi.Input[_builtins.str] datacenter_location: Location of the datacenter where the region is
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] ip_countries: Allowed countries for failover ip
        :param pulumi.Input[_builtins.str] name: Region name
        :param pulumi.Input[_builtins.str] region: Region to add to your project
        :param pulumi.Input[_builtins.str] region_name: Region name
        :param pulumi.Input[_builtins.str] service_name: Service name
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectRegionServiceArgs', 'ProjectRegionServiceArgsDict']]]] services: Details about components status
        :param pulumi.Input[_builtins.str] status: Openstack region status
        :param pulumi.Input[_builtins.str] type: Region type
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectRegionState.__new__(_ProjectRegionState)

        __props__.__dict__["availability_zones"] = availability_zones
        __props__.__dict__["continent_code"] = continent_code
        __props__.__dict__["country_code"] = country_code
        __props__.__dict__["datacenter_location"] = datacenter_location
        __props__.__dict__["ip_countries"] = ip_countries
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["services"] = services
        __props__.__dict__["status"] = status
        __props__.__dict__["type"] = type
        return ProjectRegion(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="availabilityZones")
    def availability_zones(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Availability zones of the region
        """
        return pulumi.get(self, "availability_zones")

    @_builtins.property
    @pulumi.getter(name="continentCode")
    def continent_code(self) -> pulumi.Output[_builtins.str]:
        """
        Region continent code
        """
        return pulumi.get(self, "continent_code")

    @_builtins.property
    @pulumi.getter(name="countryCode")
    def country_code(self) -> pulumi.Output[_builtins.str]:
        """
        Region country code
        """
        return pulumi.get(self, "country_code")

    @_builtins.property
    @pulumi.getter(name="datacenterLocation")
    def datacenter_location(self) -> pulumi.Output[_builtins.str]:
        """
        Location of the datacenter where the region is
        """
        return pulumi.get(self, "datacenter_location")

    @_builtins.property
    @pulumi.getter(name="ipCountries")
    def ip_countries(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Allowed countries for failover ip
        """
        return pulumi.get(self, "ip_countries")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def region(self) -> pulumi.Output[_builtins.str]:
        """
        Region to add to your project
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[_builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def services(self) -> pulumi.Output[Sequence['outputs.ProjectRegionService']]:
        """
        Details about components status
        """
        return pulumi.get(self, "services")

    @_builtins.property
    @pulumi.getter
    def status(self) -> pulumi.Output[_builtins.str]:
        """
        Openstack region status
        """
        return pulumi.get(self, "status")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Region type
        """
        return pulumi.get(self, "type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDatabasesResult',
    'AwaitableGetDatabasesResult',
    'get_databases',
    'get_databases_output',
]

@pulumi.output_type
class GetDatabasesResult:
    """
    A collection of values returned by getDatabases.
    """
    def __init__(__self__, cluster_ids=None, engine=None, id=None, service_name=None):
        if cluster_ids and not isinstance(cluster_ids, list):
            raise TypeError("Expected argument 'cluster_ids' to be a list")
        pulumi.set(__self__, "cluster_ids", cluster_ids)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter(name="clusterIds")
    def cluster_ids(self) -> Sequence[_builtins.str]:
        """
        The list of managed databases ids of the project.
        """
        return pulumi.get(self, "cluster_ids")

    @_builtins.property
    @pulumi.getter
    def engine(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "engine")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetDatabasesResult(GetDatabasesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabasesResult(
            cluster_ids=self.cluster_ids,
            engine=self.engine,
            id=self.id,
            service_name=self.service_name)


def get_databases(engine: Optional[_builtins.str] = None,
                  service_name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabasesResult:
    """
    Use this data source to get the list of managed databases of a public cloud project.

    ## Example Usage

    To get the list of database clusters service for a given engine:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dbs = ovh.CloudProjectDatabase.get_databases(service_name="XXXXXX",
        engine="YYYY")
    pulumi.export("clusterIds", dbs.cluster_ids)
    ```


    :param _builtins.str engine: The database engine you want to list. To get a full list of available engine visit: [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getDatabases:getDatabases', __args__, opts=opts, typ=GetDatabasesResult).value

    return AwaitableGetDatabasesResult(
        cluster_ids=pulumi.get(__ret__, 'cluster_ids'),
        engine=pulumi.get(__ret__, 'engine'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_databases_output(engine: Optional[pulumi.Input[_builtins.str]] = None,
                         service_name: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabasesResult]:
    """
    Use this data source to get the list of managed databases of a public cloud project.

    ## Example Usage

    To get the list of database clusters service for a given engine:

    ```python
    import pulumi
    import pulumi_ovh as ovh

    dbs = ovh.CloudProjectDatabase.get_databases(service_name="XXXXXX",
        engine="YYYY")
    pulumi.export("clusterIds", dbs.cluster_ids)
    ```


    :param _builtins.str engine: The database engine you want to list. To get a full list of available engine visit: [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getDatabases:getDatabases', __args__, opts=opts, typ=GetDatabasesResult)
    return __ret__.apply(lambda __response__: GetDatabasesResult(
        cluster_ids=pulumi.get(__response__, 'cluster_ids'),
        engine=pulumi.get(__response__, 'engine'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetInstallationTemplatesResult',
    'AwaitableGetInstallationTemplatesResult',
    'get_installation_templates',
    'get_installation_templates_output',
]

@pulumi.output_type
class GetInstallationTemplatesResult:
    """
    A collection of values returned by getInstallationTemplates.
    """
    def __init__(__self__, id=None, results=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if results and not isinstance(results, list):
            raise TypeError("Expected argument 'results' to be a list")
        pulumi.set(__self__, "results", results)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def results(self) -> Sequence[_builtins.str]:
        """
        The list of installation templates IDs available for dedicated servers.
        """
        return pulumi.get(self, "results")


class AwaitableGetInstallationTemplatesResult(GetInstallationTemplatesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstallationTemplatesResult(
            id=self.id,
            results=self.results)


def get_installation_templates(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstallationTemplatesResult:
    """
    Use this data source to get the list of installation templates available for dedicated servers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    templates = ovh.get_installation_templates()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getInstallationTemplates:getInstallationTemplates', __args__, opts=opts, typ=GetInstallationTemplatesResult).value

    return AwaitableGetInstallationTemplatesResult(
        id=pulumi.get(__ret__, 'id'),
        results=pulumi.get(__ret__, 'results'))
def get_installation_templates_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInstallationTemplatesResult]:
    """
    Use this data source to get the list of installation templates available for dedicated servers.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    templates = ovh.get_installation_templates()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getInstallationTemplates:getInstallationTemplates', __args__, opts=opts, typ=GetInstallationTemplatesResult)
    return __ret__.apply(lambda __response__: GetInstallationTemplatesResult(
        id=pulumi.get(__response__, 'id'),
        results=pulumi.get(__response__, 'results')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DedicatedServerArgs', 'DedicatedServer']

@pulumi.input_type
class DedicatedServerArgs:
    def __init__(__self__, *,
                 server_id: pulumi.Input[_builtins.str],
                 service_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a DedicatedServer resource.
        :param pulumi.Input[_builtins.str] server_id: The id of the dedicated server.
        :param pulumi.Input[_builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "server_id", server_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the dedicated server.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "server_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _DedicatedServerState:
    def __init__(__self__, *,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering DedicatedServer resources.
        :param pulumi.Input[_builtins.str] server_id: The id of the dedicated server.
        :param pulumi.Input[_builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        if server_id is not None:
            pulumi.set(__self__, "server_id", server_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the dedicated server.
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "server_id", value)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.type_token("ovh:Vrack/dedicatedServer:DedicatedServer")
class DedicatedServer(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Attach a legacy dedicated server to a vRack.

        > **NOTE:** The resource `Vrack.DedicatedServer` is intended to be used for legacy dedicated servers.<br /> Dedicated servers that have configurable network interfaces MUST use the resource `Vrack.DedicatedServerInterface` instead.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vds = ovh.vrack.DedicatedServer("vds",
            service_name="XXXX",
            server_id="67890")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] server_id: The id of the dedicated server.
        :param pulumi.Input[_builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DedicatedServerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Attach a legacy dedicated server to a vRack.

        > **NOTE:** The resource `Vrack.DedicatedServer` is intended to be used for legacy dedicated servers.<br /> Dedicated servers that have configurable network interfaces MUST use the resource `Vrack.DedicatedServerInterface` instead.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        vds = ovh.vrack.DedicatedServer("vds",
            service_name="XXXX",
            server_id="67890")
        ```

        :param str resource_name: The name of the resource.
        :param DedicatedServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DedicatedServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 server_id: Optional[pulumi.Input[_builtins.str]] = None,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DedicatedServerArgs.__new__(DedicatedServerArgs)

            if server_id is None and not opts.urn:
                raise TypeError("Missing required property 'server_id'")
            __props__.__dict__["server_id"] = server_id
            __props__.__dict__["service_name"] = service_name
        super(DedicatedServer, __self__).__init__(
            'ovh:Vrack/dedicatedServer:DedicatedServer',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            server_id: Optional[pulumi.Input[_builtins.str]] = None,
            service_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'DedicatedServer':
        """
        Get an existing DedicatedServer resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] server_id: The id of the dedicated server.
        :param pulumi.Input[_builtins.str] service_name: The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DedicatedServerState.__new__(_DedicatedServerState)

        __props__.__dict__["server_id"] = server_id
        __props__.__dict__["service_name"] = service_name
        return DedicatedServer(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the dedicated server.
        """
        return pulumi.get(self, "server_id")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[_builtins.str]:
        """
        The service name of the vrack. If omitted, the `OVH_VRACK_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'IpServiceOrderArgs',
    'IpServiceOrderArgsDict',
    'IpServiceOrderDetailArgs',
    'IpServiceOrderDetailArgsDict',
    'IpServicePlanArgs',
    'IpServicePlanArgsDict',
    'IpServicePlanConfigurationArgs',
    'IpServicePlanConfigurationArgsDict',
    'IpServicePlanOptionArgs',
    'IpServicePlanOptionArgsDict',
    'IpServicePlanOptionConfigurationArgs',
    'IpServicePlanOptionConfigurationArgsDict',
    'IpServiceRoutedToArgs',
    'IpServiceRoutedToArgsDict',
    'MoveRoutedToArgs',
    'MoveRoutedToArgsDict',
]

MYPY = False

if not MYPY:
    class IpServiceOrderArgsDict(TypedDict):
        date: NotRequired[pulumi.Input[_builtins.str]]
        """
        date
        """
        details: NotRequired[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderDetailArgsDict']]]]
        """
        Information about a Bill entry
        """
        expiration_date: NotRequired[pulumi.Input[_builtins.str]]
        """
        expiration date
        """
        order_id: NotRequired[pulumi.Input[_builtins.int]]
        """
        order id
        """
elif False:
    IpServiceOrderArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServiceOrderArgs:
    def __init__(__self__, *,
                 date: Optional[pulumi.Input[_builtins.str]] = None,
                 details: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderDetailArgs']]]] = None,
                 expiration_date: Optional[pulumi.Input[_builtins.str]] = None,
                 order_id: Optional[pulumi.Input[_builtins.int]] = None):
        """
        :param pulumi.Input[_builtins.str] date: date
        :param pulumi.Input[Sequence[pulumi.Input['IpServiceOrderDetailArgs']]] details: Information about a Bill entry
        :param pulumi.Input[_builtins.str] expiration_date: expiration date
        :param pulumi.Input[_builtins.int] order_id: order id
        """
        if date is not None:
            pulumi.set(__self__, "date", date)
        if details is not None:
            pulumi.set(__self__, "details", details)
        if expiration_date is not None:
            pulumi.set(__self__, "expiration_date", expiration_date)
        if order_id is not None:
            pulumi.set(__self__, "order_id", order_id)

    @_builtins.property
    @pulumi.getter
    def date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        date
        """
        return pulumi.get(self, "date")

    @date.setter
    def date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "date", value)

    @_builtins.property
    @pulumi.getter
    def details(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderDetailArgs']]]]:
        """
        Information about a Bill entry
        """
        return pulumi.get(self, "details")

    @details.setter
    def details(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServiceOrderDetailArgs']]]]):
        pulumi.set(self, "details", value)

    @_builtins.property
    @pulumi.getter(name="expirationDate")
    def expiration_date(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        expiration date
        """
        return pulumi.get(self, "expiration_date")

    @expiration_date.setter
    def expiration_date(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "expiration_date", value)

    @_builtins.property
    @pulumi.getter(name="orderId")
    def order_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        order id
        """
        return pulumi.get(self, "order_id")

    @order_id.setter
    def order_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "order_id", value)


if not MYPY:
    class IpServiceOrderDetailArgsDict(TypedDict):
        description: NotRequired[pulumi.Input[_builtins.str]]
        """
        Custom description on your ip.
        """
        domain: NotRequired[pulumi.Input[_builtins.str]]
        """
        expiration date
        """
        order_detail_id: NotRequired[pulumi.Input[_builtins.int]]
        """
        order detail id
        """
        quantity: NotRequired[pulumi.Input[_builtins.str]]
        """
        quantity
        """
elif False:
    IpServiceOrderDetailArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServiceOrderDetailArgs:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 domain: Optional[pulumi.Input[_builtins.str]] = None,
                 order_detail_id: Optional[pulumi.Input[_builtins.int]] = None,
                 quantity: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] description: Custom description on your ip.
        :param pulumi.Input[_builtins.str] domain: expiration date
        :param pulumi.Input[_builtins.int] order_detail_id: order detail id
        :param pulumi.Input[_builtins.str] quantity: quantity
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if order_detail_id is not None:
            pulumi.set(__self__, "order_detail_id", order_detail_id)
        if quantity is not None:
            pulumi.set(__self__, "quantity", quantity)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Custom description on your ip.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        expiration date
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "domain", value)

    @_builtins.property
    @pulumi.getter(name="orderDetailId")
    def order_detail_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        order detail id
        """
        return pulumi.get(self, "order_detail_id")

    @order_detail_id.setter
    def order_detail_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "order_detail_id", value)

    @_builtins.property
    @pulumi.getter
    def quantity(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        quantity
        """
        return pulumi.get(self, "quantity")

    @quantity.setter
    def quantity(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "quantity", value)


if not MYPY:
    class IpServicePlanArgsDict(TypedDict):
        duration: pulumi.Input[_builtins.str]
        """
        duration
        """
        plan_code: pulumi.Input[_builtins.str]
        """
        Plan code
        """
        pricing_mode: pulumi.Input[_builtins.str]
        """
        Pricing model identifier
        """
        catalog_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Catalog name
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['IpServicePlanConfigurationArgsDict']]]]
        """
        Representation of a configuration item for personalizing product
        """
elif False:
    IpServicePlanArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServicePlanArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[_builtins.str],
                 plan_code: pulumi.Input[_builtins.str],
                 pricing_mode: pulumi.Input[_builtins.str],
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[_builtins.str] duration: duration
        :param pulumi.Input[_builtins.str] plan_code: Plan code
        :param pulumi.Input[_builtins.str] pricing_mode: Pricing model identifier
        :param pulumi.Input[_builtins.str] catalog_name: Catalog name
        :param pulumi.Input[Sequence[pulumi.Input['IpServicePlanConfigurationArgs']]] configurations: Representation of a configuration item for personalizing product
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> pulumi.Input[_builtins.str]:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "duration", value)

    @_builtins.property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[_builtins.str]:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "plan_code", value)

    @_builtins.property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[_builtins.str]:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanConfigurationArgs']]]]:
        """
        Representation of a configuration item for personalizing product
        """
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class IpServicePlanConfigurationArgsDict(TypedDict):
        label: pulumi.Input[_builtins.str]
        """
        Identifier of the resource
        """
        value: pulumi.Input[_builtins.str]
        """
        Path to the resource in API.OVH.COM
        """
elif False:
    IpServicePlanConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServicePlanConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] label: Identifier of the resource
        :param pulumi.Input[_builtins.str] value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class IpServicePlanOptionArgsDict(TypedDict):
        duration: pulumi.Input[_builtins.str]
        """
        duration
        """
        plan_code: pulumi.Input[_builtins.str]
        """
        Plan code
        """
        pricing_mode: pulumi.Input[_builtins.str]
        """
        Pricing model identifier
        """
        catalog_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        Catalog name
        """
        configurations: NotRequired[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionConfigurationArgsDict']]]]
        """
        Representation of a configuration item for personalizing product. The list of available configurations can be retrieved using call [GET /order/cart/{cartId}/item/{itemId}/requiredConfiguration](https://eu.api.ovh.com/console/?section=%2Forder&branch=v1#get-/order/cart/-cartId-/item/-itemId-/requiredConfiguration)
        """
elif False:
    IpServicePlanOptionArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServicePlanOptionArgs:
    def __init__(__self__, *,
                 duration: pulumi.Input[_builtins.str],
                 plan_code: pulumi.Input[_builtins.str],
                 pricing_mode: pulumi.Input[_builtins.str],
                 catalog_name: Optional[pulumi.Input[_builtins.str]] = None,
                 configurations: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionConfigurationArgs']]]] = None):
        """
        :param pulumi.Input[_builtins.str] duration: duration
        :param pulumi.Input[_builtins.str] plan_code: Plan code
        :param pulumi.Input[_builtins.str] pricing_mode: Pricing model identifier
        :param pulumi.Input[_builtins.str] catalog_name: Catalog name
        :param pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionConfigurationArgs']]] configurations: Representation of a configuration item for personalizing product. The list of available configurations can be retrieved using call [GET /order/cart/{cartId}/item/{itemId}/requiredConfiguration](https://eu.api.ovh.com/console/?section=%2Forder&branch=v1#get-/order/cart/-cartId-/item/-itemId-/requiredConfiguration)
        """
        pulumi.set(__self__, "duration", duration)
        pulumi.set(__self__, "plan_code", plan_code)
        pulumi.set(__self__, "pricing_mode", pricing_mode)
        if catalog_name is not None:
            pulumi.set(__self__, "catalog_name", catalog_name)
        if configurations is not None:
            pulumi.set(__self__, "configurations", configurations)

    @_builtins.property
    @pulumi.getter
    def duration(self) -> pulumi.Input[_builtins.str]:
        """
        duration
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "duration", value)

    @_builtins.property
    @pulumi.getter(name="planCode")
    def plan_code(self) -> pulumi.Input[_builtins.str]:
        """
        Plan code
        """
        return pulumi.get(self, "plan_code")

    @plan_code.setter
    def plan_code(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "plan_code", value)

    @_builtins.property
    @pulumi.getter(name="pricingMode")
    def pricing_mode(self) -> pulumi.Input[_builtins.str]:
        """
        Pricing model identifier
        """
        return pulumi.get(self, "pricing_mode")

    @pricing_mode.setter
    def pricing_mode(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "pricing_mode", value)

    @_builtins.property
    @pulumi.getter(name="catalogName")
    def catalog_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Catalog name
        """
        return pulumi.get(self, "catalog_name")

    @catalog_name.setter
    def catalog_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "catalog_name", value)

    @_builtins.property
    @pulumi.getter
    def configurations(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionConfigurationArgs']]]]:
        """
        Representation of a configuration item for personalizing product. The list of available configurations can be retrieved using call [GET /order/cart/{cartId}/item/{itemId}/requiredConfiguration](https://eu.api.ovh.com/console/?section=%2Forder&branch=v1#get-/order/cart/-cartId-/item/-itemId-/requiredConfiguration)
        """
        return pulumi.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['IpServicePlanOptionConfigurationArgs']]]]):
        pulumi.set(self, "configurations", value)


if not MYPY:
    class IpServicePlanOptionConfigurationArgsDict(TypedDict):
        label: pulumi.Input[_builtins.str]
        """
        Identifier of the resource
        """
        value: pulumi.Input[_builtins.str]
        """
        Path to the resource in API.OVH.COM
        """
elif False:
    IpServicePlanOptionConfigurationArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServicePlanOptionConfigurationArgs:
    def __init__(__self__, *,
                 label: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] label: Identifier of the resource
        :param pulumi.Input[_builtins.str] value: Path to the resource in API.OVH.COM
        """
        pulumi.set(__self__, "label", label)
        pulumi.set(__self__, "value", value)

    @_builtins.property
    @pulumi.getter
    def label(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the resource
        """
        return pulumi.get(self, "label")

    @label.setter
    def label(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "label", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        Path to the resource in API.OVH.COM
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)


if not MYPY:
    class IpServiceRoutedToArgsDict(TypedDict):
        service_name: NotRequired[pulumi.Input[_builtins.str]]
        """
        service name
        """
elif False:
    IpServiceRoutedToArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class IpServiceRoutedToArgs:
    def __init__(__self__, *,
                 service_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        :param pulumi.Input[_builtins.str] service_name: service name
        """
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "service_name", value)


if not MYPY:
    class MoveRoutedToArgsDict(TypedDict):
        service_name: pulumi.Input[_builtins.str]
        """
        Name of the service to route the IP to. IP will be parked if this value is an empty string
        """
elif False:
    MoveRoutedToArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class MoveRoutedToArgs:
    def __init__(__self__, *,
                 service_name: pulumi.Input[_builtins.str]):
        """
        :param pulumi.Input[_builtins.str] service_name: Name of the service to route the IP to. IP will be parked if this value is an empty string
        """
        pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the service to route the IP to. IP will be parked if this value is an empty string
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "service_name", value)





# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetStorageEfsResult',
    'AwaitableGetStorageEfsResult',
    'get_storage_efs',
    'get_storage_efs_output',
]

@pulumi.output_type
class GetStorageEfsResult:
    """
    A collection of values returned by getStorageEfs.
    """
    def __init__(__self__, created_at=None, iam=None, id=None, name=None, performance_level=None, product=None, quota=None, region=None, service_name=None, status=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if iam and not isinstance(iam, dict):
            raise TypeError("Expected argument 'iam' to be a dict")
        pulumi.set(__self__, "iam", iam)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if performance_level and not isinstance(performance_level, str):
            raise TypeError("Expected argument 'performance_level' to be a str")
        pulumi.set(__self__, "performance_level", performance_level)
        if product and not isinstance(product, str):
            raise TypeError("Expected argument 'product' to be a str")
        pulumi.set(__self__, "product", product)
        if quota and not isinstance(quota, float):
            raise TypeError("Expected argument 'quota' to be a float")
        pulumi.set(__self__, "quota", quota)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Service creation date
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def iam(self) -> 'outputs.GetStorageEfsIamResult':
        """
        IAM resource metadata
        """
        return pulumi.get(self, "iam")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Service ID
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="performanceLevel")
    def performance_level(self) -> _builtins.str:
        """
        Service performance level
        """
        return pulumi.get(self, "performance_level")

    @_builtins.property
    @pulumi.getter
    def product(self) -> _builtins.str:
        """
        Product name
        """
        return pulumi.get(self, "product")

    @_builtins.property
    @pulumi.getter
    def quota(self) -> _builtins.float:
        """
        Service quota
        """
        return pulumi.get(self, "quota")

    @_builtins.property
    @pulumi.getter
    def region(self) -> _builtins.str:
        """
        Service region
        """
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def status(self) -> _builtins.str:
        """
        Service status
        """
        return pulumi.get(self, "status")


class AwaitableGetStorageEfsResult(GetStorageEfsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetStorageEfsResult(
            created_at=self.created_at,
            iam=self.iam,
            id=self.id,
            name=self.name,
            performance_level=self.performance_level,
            product=self.product,
            quota=self.quota,
            region=self.region,
            service_name=self.service_name,
            status=self.status)


def get_storage_efs(service_name: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetStorageEfsResult:
    """
    Get information about an EFS service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    efs = ovh.get_storage_efs(service_name="XXX")
    ```


    :param _builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:index/getStorageEfs:getStorageEfs', __args__, opts=opts, typ=GetStorageEfsResult).value

    return AwaitableGetStorageEfsResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        iam=pulumi.get(__ret__, 'iam'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        performance_level=pulumi.get(__ret__, 'performance_level'),
        product=pulumi.get(__ret__, 'product'),
        quota=pulumi.get(__ret__, 'quota'),
        region=pulumi.get(__ret__, 'region'),
        service_name=pulumi.get(__ret__, 'service_name'),
        status=pulumi.get(__ret__, 'status'))
def get_storage_efs_output(service_name: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetStorageEfsResult]:
    """
    Get information about an EFS service.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    efs = ovh.get_storage_efs(service_name="XXX")
    ```


    :param _builtins.str service_name: Service name
    """
    __args__ = dict()
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:index/getStorageEfs:getStorageEfs', __args__, opts=opts, typ=GetStorageEfsResult)
    return __ret__.apply(lambda __response__: GetStorageEfsResult(
        created_at=pulumi.get(__response__, 'created_at'),
        iam=pulumi.get(__response__, 'iam'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        performance_level=pulumi.get(__response__, 'performance_level'),
        product=pulumi.get(__response__, 'product'),
        quota=pulumi.get(__response__, 'quota'),
        region=pulumi.get(__response__, 'region'),
        service_name=pulumi.get(__response__, 'service_name'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPolicyResult',
    'AwaitableGetPolicyResult',
    'get_policy',
    'get_policy_output',
]

@pulumi.output_type
class GetPolicyResult:
    """
    A collection of values returned by getPolicy.
    """
    def __init__(__self__, allows=None, created_at=None, denies=None, description=None, excepts=None, id=None, identities=None, name=None, owner=None, permissions_groups=None, read_only=None, resources=None, updated_at=None):
        if allows and not isinstance(allows, list):
            raise TypeError("Expected argument 'allows' to be a list")
        pulumi.set(__self__, "allows", allows)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if denies and not isinstance(denies, list):
            raise TypeError("Expected argument 'denies' to be a list")
        pulumi.set(__self__, "denies", denies)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if excepts and not isinstance(excepts, list):
            raise TypeError("Expected argument 'excepts' to be a list")
        pulumi.set(__self__, "excepts", excepts)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identities and not isinstance(identities, list):
            raise TypeError("Expected argument 'identities' to be a list")
        pulumi.set(__self__, "identities", identities)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if owner and not isinstance(owner, str):
            raise TypeError("Expected argument 'owner' to be a str")
        pulumi.set(__self__, "owner", owner)
        if permissions_groups and not isinstance(permissions_groups, list):
            raise TypeError("Expected argument 'permissions_groups' to be a list")
        pulumi.set(__self__, "permissions_groups", permissions_groups)
        if read_only and not isinstance(read_only, bool):
            raise TypeError("Expected argument 'read_only' to be a bool")
        pulumi.set(__self__, "read_only", read_only)
        if resources and not isinstance(resources, list):
            raise TypeError("Expected argument 'resources' to be a list")
        pulumi.set(__self__, "resources", resources)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def allows(self) -> Optional[Sequence[_builtins.str]]:
        """
        Set of actions allowed by the policy.
        """
        return pulumi.get(self, "allows")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Creation date of this group.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def denies(self) -> Optional[Sequence[_builtins.str]]:
        """
        Set of actions that will be denied no matter what policy exists.
        """
        return pulumi.get(self, "denies")

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[_builtins.str]:
        """
        Group description.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def excepts(self) -> Optional[Sequence[_builtins.str]]:
        """
        Set of actions that will be subtracted from the `allow` list.
        """
        return pulumi.get(self, "excepts")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identities(self) -> Sequence[_builtins.str]:
        """
        Set of identities affected by the policy.
        """
        return pulumi.get(self, "identities")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the policy.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def owner(self) -> _builtins.str:
        """
        Owner of the policy.
        """
        return pulumi.get(self, "owner")

    @_builtins.property
    @pulumi.getter(name="permissionsGroups")
    def permissions_groups(self) -> Optional[Sequence[_builtins.str]]:
        """
        Set of permissions groups that apply to the policy.
        """
        return pulumi.get(self, "permissions_groups")

    @_builtins.property
    @pulumi.getter(name="readOnly")
    def read_only(self) -> _builtins.bool:
        """
        Indicates that the policy is a default one.
        """
        return pulumi.get(self, "read_only")

    @_builtins.property
    @pulumi.getter
    def resources(self) -> Sequence[_builtins.str]:
        """
        Set of resources affected by the policy.
        """
        return pulumi.get(self, "resources")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> _builtins.str:
        """
        Date of the last update of this group.
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetPolicyResult(GetPolicyResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPolicyResult(
            allows=self.allows,
            created_at=self.created_at,
            denies=self.denies,
            description=self.description,
            excepts=self.excepts,
            id=self.id,
            identities=self.identities,
            name=self.name,
            owner=self.owner,
            permissions_groups=self.permissions_groups,
            read_only=self.read_only,
            resources=self.resources,
            updated_at=self.updated_at)


def get_policy(allows: Optional[Sequence[_builtins.str]] = None,
               denies: Optional[Sequence[_builtins.str]] = None,
               description: Optional[_builtins.str] = None,
               excepts: Optional[Sequence[_builtins.str]] = None,
               id: Optional[_builtins.str] = None,
               permissions_groups: Optional[Sequence[_builtins.str]] = None,
               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPolicyResult:
    """
    Use this data source to retrieve am IAM policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_policy = ovh.Iam.get_policy(id="my_policy_id")
    ```


    :param Sequence[_builtins.str] allows: Set of actions allowed by the policy.
    :param Sequence[_builtins.str] denies: Set of actions that will be denied no matter what policy exists.
    :param _builtins.str description: Group description.
    :param Sequence[_builtins.str] excepts: Set of actions that will be subtracted from the `allow` list.
    :param _builtins.str id: UUID of the policy.
    :param Sequence[_builtins.str] permissions_groups: Set of permissions groups that apply to the policy.
    """
    __args__ = dict()
    __args__['allows'] = allows
    __args__['denies'] = denies
    __args__['description'] = description
    __args__['excepts'] = excepts
    __args__['id'] = id
    __args__['permissionsGroups'] = permissions_groups
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult).value

    return AwaitableGetPolicyResult(
        allows=pulumi.get(__ret__, 'allows'),
        created_at=pulumi.get(__ret__, 'created_at'),
        denies=pulumi.get(__ret__, 'denies'),
        description=pulumi.get(__ret__, 'description'),
        excepts=pulumi.get(__ret__, 'excepts'),
        id=pulumi.get(__ret__, 'id'),
        identities=pulumi.get(__ret__, 'identities'),
        name=pulumi.get(__ret__, 'name'),
        owner=pulumi.get(__ret__, 'owner'),
        permissions_groups=pulumi.get(__ret__, 'permissions_groups'),
        read_only=pulumi.get(__ret__, 'read_only'),
        resources=pulumi.get(__ret__, 'resources'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_policy_output(allows: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      denies: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      description: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                      excepts: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      id: Optional[pulumi.Input[_builtins.str]] = None,
                      permissions_groups: Optional[pulumi.Input[Optional[Sequence[_builtins.str]]]] = None,
                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPolicyResult]:
    """
    Use this data source to retrieve am IAM policy.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_policy = ovh.Iam.get_policy(id="my_policy_id")
    ```


    :param Sequence[_builtins.str] allows: Set of actions allowed by the policy.
    :param Sequence[_builtins.str] denies: Set of actions that will be denied no matter what policy exists.
    :param _builtins.str description: Group description.
    :param Sequence[_builtins.str] excepts: Set of actions that will be subtracted from the `allow` list.
    :param _builtins.str id: UUID of the policy.
    :param Sequence[_builtins.str] permissions_groups: Set of permissions groups that apply to the policy.
    """
    __args__ = dict()
    __args__['allows'] = allows
    __args__['denies'] = denies
    __args__['description'] = description
    __args__['excepts'] = excepts
    __args__['id'] = id
    __args__['permissionsGroups'] = permissions_groups
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Iam/getPolicy:getPolicy', __args__, opts=opts, typ=GetPolicyResult)
    return __ret__.apply(lambda __response__: GetPolicyResult(
        allows=pulumi.get(__response__, 'allows'),
        created_at=pulumi.get(__response__, 'created_at'),
        denies=pulumi.get(__response__, 'denies'),
        description=pulumi.get(__response__, 'description'),
        excepts=pulumi.get(__response__, 'excepts'),
        id=pulumi.get(__response__, 'id'),
        identities=pulumi.get(__response__, 'identities'),
        name=pulumi.get(__response__, 'name'),
        owner=pulumi.get(__response__, 'owner'),
        permissions_groups=pulumi.get(__response__, 'permissions_groups'),
        read_only=pulumi.get(__response__, 'read_only'),
        resources=pulumi.get(__response__, 'resources'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetKubeIpRestrictionsResult',
    'AwaitableGetKubeIpRestrictionsResult',
    'get_kube_ip_restrictions',
    'get_kube_ip_restrictions_output',
]

@pulumi.output_type
class GetKubeIpRestrictionsResult:
    """
    A collection of values returned by getKubeIpRestrictions.
    """
    def __init__(__self__, id=None, ips=None, kube_id=None, service_name=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ips and not isinstance(ips, list):
            raise TypeError("Expected argument 'ips' to be a list")
        pulumi.set(__self__, "ips", ips)
        if kube_id and not isinstance(kube_id, str):
            raise TypeError("Expected argument 'kube_id' to be a str")
        pulumi.set(__self__, "kube_id", kube_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def ips(self) -> Sequence[_builtins.str]:
        """
        The list of CIDRs that restricts the access to the API server.
        """
        return pulumi.get(self, "ips")

    @_builtins.property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "kube_id")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")


class AwaitableGetKubeIpRestrictionsResult(GetKubeIpRestrictionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKubeIpRestrictionsResult(
            id=self.id,
            ips=self.ips,
            kube_id=self.kube_id,
            service_name=self.service_name)


def get_kube_ip_restrictions(kube_id: Optional[_builtins.str] = None,
                             service_name: Optional[_builtins.str] = None,
                             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKubeIpRestrictionsResult:
    """
    Use this data source to get a OVHcloud Managed Kubernetes Service cluster IP restrictions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ip_restrictions = ovh.CloudProject.get_kube_ip_restrictions(service_name="XXXXXX",
        kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    pulumi.export("ips", ip_restrictions.ips)
    ```


    :param _builtins.str kube_id: The id of the managed kubernetes cluster.
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['kubeId'] = kube_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getKubeIpRestrictions:getKubeIpRestrictions', __args__, opts=opts, typ=GetKubeIpRestrictionsResult).value

    return AwaitableGetKubeIpRestrictionsResult(
        id=pulumi.get(__ret__, 'id'),
        ips=pulumi.get(__ret__, 'ips'),
        kube_id=pulumi.get(__ret__, 'kube_id'),
        service_name=pulumi.get(__ret__, 'service_name'))
def get_kube_ip_restrictions_output(kube_id: Optional[pulumi.Input[_builtins.str]] = None,
                                    service_name: Optional[pulumi.Input[_builtins.str]] = None,
                                    opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKubeIpRestrictionsResult]:
    """
    Use this data source to get a OVHcloud Managed Kubernetes Service cluster IP restrictions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    ip_restrictions = ovh.CloudProject.get_kube_ip_restrictions(service_name="XXXXXX",
        kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    pulumi.export("ips", ip_restrictions.ips)
    ```


    :param _builtins.str kube_id: The id of the managed kubernetes cluster.
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['kubeId'] = kube_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getKubeIpRestrictions:getKubeIpRestrictions', __args__, opts=opts, typ=GetKubeIpRestrictionsResult)
    return __ret__.apply(lambda __response__: GetKubeIpRestrictionsResult(
        id=pulumi.get(__response__, 'id'),
        ips=pulumi.get(__response__, 'ips'),
        kube_id=pulumi.get(__response__, 'kube_id'),
        service_name=pulumi.get(__response__, 'service_name')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetKafkaAclResult',
    'AwaitableGetKafkaAclResult',
    'get_kafka_acl',
    'get_kafka_acl_output',
]

@pulumi.output_type
class GetKafkaAclResult:
    """
    A collection of values returned by getKafkaAcl.
    """
    def __init__(__self__, cluster_id=None, id=None, permission=None, service_name=None, topic=None, username=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if permission and not isinstance(permission, str):
            raise TypeError("Expected argument 'permission' to be a str")
        pulumi.set(__self__, "permission", permission)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if topic and not isinstance(topic, str):
            raise TypeError("Expected argument 'topic' to be a str")
        pulumi.set(__self__, "topic", topic)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)

    @_builtins.property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def permission(self) -> _builtins.str:
        """
        Permission to give to this username on this topic.
        """
        return pulumi.get(self, "permission")

    @_builtins.property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> _builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @_builtins.property
    @pulumi.getter
    def topic(self) -> _builtins.str:
        """
        Topic affected by this ACL.
        """
        return pulumi.get(self, "topic")

    @_builtins.property
    @pulumi.getter
    def username(self) -> _builtins.str:
        """
        Username affected by this ACL.
        """
        return pulumi.get(self, "username")


class AwaitableGetKafkaAclResult(GetKafkaAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKafkaAclResult(
            cluster_id=self.cluster_id,
            id=self.id,
            permission=self.permission,
            service_name=self.service_name,
            topic=self.topic,
            username=self.username)


def get_kafka_acl(cluster_id: Optional[_builtins.str] = None,
                  id: Optional[_builtins.str] = None,
                  service_name: Optional[_builtins.str] = None,
                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKafkaAclResult:
    """
    Use this data source to get information about an ACL of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    acl = ovh.CloudProjectDatabase.get_kafka_acl(service_name="XXX",
        cluster_id="YYY",
        id="ZZZ")
    pulumi.export("aclPermission", acl.permission)
    ```


    :param _builtins.str cluster_id: Cluster ID
    :param _builtins.str id: ACL ID
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getKafkaAcl:getKafkaAcl', __args__, opts=opts, typ=GetKafkaAclResult).value

    return AwaitableGetKafkaAclResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        id=pulumi.get(__ret__, 'id'),
        permission=pulumi.get(__ret__, 'permission'),
        service_name=pulumi.get(__ret__, 'service_name'),
        topic=pulumi.get(__ret__, 'topic'),
        username=pulumi.get(__ret__, 'username'))
def get_kafka_acl_output(cluster_id: Optional[pulumi.Input[_builtins.str]] = None,
                         id: Optional[pulumi.Input[_builtins.str]] = None,
                         service_name: Optional[pulumi.Input[_builtins.str]] = None,
                         opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKafkaAclResult]:
    """
    Use this data source to get information about an ACL of a kafka cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    acl = ovh.CloudProjectDatabase.get_kafka_acl(service_name="XXX",
        cluster_id="YYY",
        id="ZZZ")
    pulumi.export("aclPermission", acl.permission)
    ```


    :param _builtins.str cluster_id: Cluster ID
    :param _builtins.str id: ACL ID
    :param _builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['id'] = id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getKafkaAcl:getKafkaAcl', __args__, opts=opts, typ=GetKafkaAclResult)
    return __ret__.apply(lambda __response__: GetKafkaAclResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        id=pulumi.get(__response__, 'id'),
        permission=pulumi.get(__response__, 'permission'),
        service_name=pulumi.get(__response__, 'service_name'),
        topic=pulumi.get(__response__, 'topic'),
        username=pulumi.get(__response__, 'username')))
